Riverbed SteelScript for SteelCentral NetShark
==============================================

This package provides device specific bindings for interacting
with Riverbed SteelCentral NetShark devices as part of the Riverbed
SteelScript for Python.

For a complete guide to installation, see:

  `https://support.riverbed.com/apis/steelscript/index.html <https://support.riverbed.com/apis/steelscript/index.html>`_

License
=======

Copyright (c) 2015 Riverbed Technology, Inc.

SteelScript-NetShark is licensed under the terms and conditions of the MIT
License accompanying the software ("License").  SteelScript-NetShark is
distributed "AS IS" as set forth in the License.
